@@ -26,7 +26,7 @@ performance is on boxes and configs other than my own.
 =cut
 
 our $opt_l;
-getopt( 'l:' );
+getopt('l:');
 die "Must specify location of Nagios status log with -l option."
     if ( !$opt_l );
 
@@ -38,9 +38,8 @@ my $bench_postparse = Benchmark->new;
 #print Dumper( $log );
 
 foreach my $host ( $log->list_hosts ) {
-    my $obj = $log->host( $host );
-    printf "Host: %s Last Update: %d\n",
-                $obj->host_name, $obj->last_update;
+    my $obj = $log->host($host);
+    printf "Host: %s Last Update: %d\n", $obj->host_name, $obj->last_update;
 
 }
 
@@ -50,6 +49,6 @@ printf "Started at %d", $prog->program_start;
 my $bench_postprint = Benchmark->new;
 
 printf "\nTime to parse: %s\nTime to print: %s\n\n",
-        timestr(timediff( $bench_postparse, $bench_begin )), 
-        timestr(timediff( $bench_postprint, $bench_postparse ));
+    timestr( timediff( $bench_postparse, $bench_begin ) ),
+    timestr( timediff( $bench_postprint, $bench_postparse ) );
 
